﻿--[[ Here you can define the slash commands by inserting them into a table.

    The table consists of 1 child tables and some data attributes:
        desc        with the general description/headline for this slash command
        slashcmd    the name of index of the SlashCmdList[index]
        printall    switch for printing hidden commands (true or nil)
        cmds        a table with all commands your addon can process
    The cmds subtable must contain for each command following attributes:
        cmd         contains the command name as you use it, only one word is optimal to process
    The cmds subtable can contain further these attributes:
        param       contains the possible params
        desc        contains the description for the command
        show        true if you want to print it as help per default
        indent      a number, how often your desc should be indented (it ommits /slashcommand then)
        func        contains the called function for this command

    Please be aware, that we use always the function of the first inserted command, if there are
    more than one with the same cmd attribute.

    -- Example for: /ase command param1 param2 param3
    SlashCmdList["ASE"] = function(msg)
        // do whatever you wish with the chat commands in msg
        // local command, params = msg:match("^(%S*)%s*(.-)$"); -- Divide into command and parameter
    end
    SLASH_ASE1 = "/ase";
    SLASH_ASE2 = "/aslashexample";
    local yourCmdTable = {
        desc = "Your Slash command Help Header----------",
        cmds = { },
    };
    tinsert(yourCmdTable.cmds, {
        cmd = "command1",
        desc = "Just an example command",
        show = true,
        func = function(args)
            print("Hello world -> " .. args);
        end }
    );

--]]

-- General functions
local COLOR_GREYEDOUT = "808080";
local COLOR_INDENT    = "C0C0C0";

local function getFunc( cmdTable, cmd )
    local func;
    if cmd == nil or cmd == "" then
        return func;
    end
    for i=1, table.getn(cmdTable.cmds) do
        if ( cmdTable.cmds[i].cmd == cmd ) then
            func = cmdTable.cmds[i].func;
            break;
        end
    end
    return func;
end

local function printHelp( cmdTable )
    local cmdlist = "SLASH_" .. cmdTable.slashcmd;
    local txt = "";

    local index = 1;
    while getglobal(cmdlist .. index) ~= nil do
        txt = txt .. "  " .. getglobal(cmdlist .. index);

        index = index + 1;
    end
    FlagRSPStatic:PrintM(cmdTable.desc);
    print("Slash commands: " .. txt);

    local main = getglobal(cmdlist .. "1");
    for cmd, t in pairs(cmdTable.cmds) do
        if t.show or cmdTable.printall then
            local help = "";
            if t.cmd ~= nil and t.cmd ~= "" then
                local desc = "";
                local param = t.param or "";
                if param ~= "" then
                    param = " " .. param;
                end
                if t.desc then
                    -- desc = desc .. " --> " .. t.desc;
                    desc = t.desc;
                end
                if t.indent and tonumber(t.indent) and t.indent > 0 then
                    help = "|cFF"..COLOR_INDENT .. help;
                    -- help = help .. strrep("    ",t.indent) .. t.cmd .. param .. desc;
                    help = help .. desc;
                    help = help .. "|r";
                else
                    -- help = main .. " " .. t.cmd .. param .. desc;
                    help = desc;
                end
                if t.show == nil or t.show == false then
                    help = "|cFF" .. COLOR_GREYEDOUT .. help .. "|r";
                end
            else
                help = "|cFF90FF90~"..t.desc .. "~|r";
            end

            print(help);
        end
    end
end



-- Slash handling for /rsp, cmdTableRSP

local cmdTableRSP = {};
SlashCmdList["RSP"] = function( msg, ... ) -- cmdTable, args
    local command, args = msg:match("^(%S*)%s*(.-)$");

	local func = getFunc(cmdTableRSP, command);
	
	if ( func ~= nil ) then
		func(args);
    else
        printHelp( cmdTableRSP );
    end
end
SLASH_RSP1 = "/rsp";
SLASH_RSP2 = "/flagrsp";

cmdTableRSP = {
    desc = strsub(FlagRSP_Locale_Help[0],1,42);
    slashcmd = "RSP",
    cmds = { },
    -- printall = true;
};
tinsert( cmdTableRSP.cmds, { -- Part: RP Flag
    desc = "RP Flag",
    -- show = true,
    }
);
-- tinsert( cmdTableRSP.cmds, { -- RP Surname
    -- cmd = FlagRSP_Locale_Surname_Cmd,
    -- desc = FlagRSP_Locale_Help[6] .. " (Disabled)",
    -- func = function(args) FlagRSPStatic:PrintM("Set surname is out of order, sorry!"); end
    -- }
-- );
-- tinsert( cmdTableRSP.cmds, { -- RP Firstname
    -- cmd = FlagRSP_Locale_Firstname_Cmd,
    -- desc = FlagRSP_Locale_Help[7] .. " (Disabled)",
    -- func = function(args) FlagRSPStatic:PrintM("Set first name is out of order, sorry!"); end
    -- }
-- );
-- tinsert( cmdTableRSP.cmds, { -- RP Fullname
    -- cmd = "fullname",
    -- desc = "/rsp fullname <FULLNAME> --> sets your fullname to <FULLNAME>",
    -- -- show = true,
    -- func = function(args)
		-- FlagRSP:setFullname((string.sub(msg, string.len("fullname")+2, string.len(msg))));
        -- FlagRSPProtocol:UpdateOwn();
		-- FriendlistCharFrame_Load();
    -- end
    -- }
-- );
-- tinsert( cmdTableRSP.cmds, { -- RP Title
    -- cmd = FlagRSP_Locale_Title_Cmd,
    -- desc = FlagRSP_Locale_Help[8],
    -- -- show = true,
    -- func = function(args)
		-- FlagRSP:setTitle(string.sub(msg, string.len(FlagRSP_Locale_Title_Cmd)+2, string.len(msg)));
        -- FlagRSPProtocol:UpdateOwn();
		-- FriendlistCharFrame_Load();
    -- end
    -- }
-- );
tinsert( cmdTableRSP.cmds, { -- Overview RP Flag
    cmd = "[" .. FlagRSP_Locale_Beginner_Cmd .. "/" .. FlagRSP_Locale_Casual_Cmd .. "/" .. FlagRSP_Locale_Normal_Cmd .. "/" .. FlagRSP_Locale_Fulltime_Cmd .. "/" .. FlagRSP_Locale_NoRP_Cmd .. "]",
    desc = FlagRSP_Locale_Help[9],
    -- show = true,
    }
);
tinsert( cmdTableRSP.cmds, { -- RP Flag Beginner
    cmd = FlagRSP_Locale_Beginner_Cmd,
    desc = FlagRSP_Locale_Help[10],
    -- show = true,
    indent = 1,
    func = function(args)
        FlagRSP:setRPFlag(4);
        FlagRSPProtocol:UpdateOwn();
		FriendlistCharFrame_Load();
    end
    }
);
tinsert( cmdTableRSP.cmds, { -- RP Flag Casual
    cmd = FlagRSP_Locale_Casual_Cmd,
    desc = FlagRSP_Locale_Help[11],
    -- show = true,
    indent = 1,
    func = function(args)
		FlagRSP:setRPFlag(2);
        FlagRSPProtocol:UpdateOwn();
		FriendlistCharFrame_Load();
    end
    }
);
tinsert( cmdTableRSP.cmds, { -- RP Flag Normal
    cmd = FlagRSP_Locale_Normal_Cmd,
    desc = FlagRSP_Locale_Help[12],
    -- show = true,
    indent = 1,
    func = function(args)
		FlagRSP:setRPFlag(1);
        FlagRSPProtocol:UpdateOwn();
		FriendlistCharFrame_Load();
    end
    }
);
tinsert( cmdTableRSP.cmds, { -- RP Flag Fulltime
    cmd = FlagRSP_Locale_Fulltime_Cmd,
    desc = FlagRSP_Locale_Help[13],
    -- show = true,
    indent = 1,
    func = function(args)
		FlagRSP:setRPFlag(3);
        FlagRSPProtocol:UpdateOwn();
		FriendlistCharFrame_Load();
    end
    }
);
tinsert( cmdTableRSP.cmds, { -- RP Flag None
    cmd = FlagRSP_Locale_NoRP_Cmd,
    desc = FlagRSP_Locale_Help[14],
    -- show = true,
    indent = 1,
    func = function(args)
		FlagRSP:setRPFlag(0);
        FlagRSPProtocol:UpdateOwn();
		FriendlistCharFrame_Load();
    end
    }
);
tinsert( cmdTableRSP.cmds, { -- Overview Char Status
    cmd = "[" .. FlagRSP_Locale_OOC_Cmd .. "/" .. FlagRSP_Locale_IC_Cmd .. "/" .. FlagRSP_Locale_ICFFA_Cmd .. "/" .. FlagRSP_Locale_ST_Cmd .. "/" .. FlagRSP_Locale_NoCStatus_Cmd .. "]",
    desc = FlagRSP_Locale_Help[15],
    -- show = true,
    }
);
tinsert( cmdTableRSP.cmds, { -- Char Status OOC
    cmd = FlagRSP_Locale_OOC_Cmd,
    desc = FlagRSP_Locale_Help[16],
    -- show = true,
    indent = 1,
    func = function(args)
		FlagRSP:setCharStatus(1);
        FlagRSPProtocol:UpdateOwn();
		FriendlistCharFrame_Load();
    end
    }
);
tinsert( cmdTableRSP.cmds, { -- Char Status IC
    cmd = FlagRSP_Locale_IC_Cmd,
    desc = FlagRSP_Locale_Help[17],
    -- show = true,
    indent = 1,
    func = function(args)
		FlagRSP:setCharStatus(2);
        FlagRSPProtocol:UpdateOwn();
		FriendlistCharFrame_Load();
    end
    }
);
tinsert( cmdTableRSP.cmds, { -- Char Status ICFFA
    cmd = FlagRSP_Locale_ICFFA_Cmd,
    desc = FlagRSP_Locale_Help[18],
    -- show = true,
    indent = 1,
    func = function(args)
		FlagRSP:setCharStatus(3);
        FlagRSPProtocol:UpdateOwn();
		FriendlistCharFrame_Load();
    end
    }
);
tinsert( cmdTableRSP.cmds, { -- Char Status ST
    cmd = FlagRSP_Locale_ST_Cmd,
    desc = FlagRSP_Locale_Help[19],
    -- show = true,
    indent = 1,
    func = function(args)
		FlagRSP:setCharStatus(4);
        FlagRSPProtocol:UpdateOwn();
		FriendlistCharFrame_Load();
    end
    }
);
tinsert( cmdTableRSP.cmds, { -- Char Status
    cmd = FlagRSP_Locale_NoCStatus_Cmd,
    desc = FlagRSP_Locale_Help[20],
    -- show = true,
    indent = 1,
    func = function(args)
		FlagRSP:setCharStatus(0);
        FlagRSPProtocol:UpdateOwn();
		FriendlistCharFrame_Load();
    end
    }
);
tinsert( cmdTableRSP.cmds, { -- Part: RP Config
    desc = "RP Config",
    show = true,
    }
);
tinsert( cmdTableRSP.cmds, { -- Display Names
    cmd = FlagRSP_Locale_HideNames_Cmd,
    desc = FlagRSP_Locale_Help[2],
    func = function(args) FlagRSP:toggleHideNames(); end
    }
);
tinsert( cmdTableRSP.cmds, { -- Display Level
    cmd = FlagRSP_Locale_LevelDisp_Cmd,
    desc = FlagRSP_Locale_Help[3],
    func = function(args) FlagRSP:toggleLevelDisp(); end
    }
);
tinsert( cmdTableRSP.cmds, { -- Display Game Title
    cmd = FlagRSP_Locale_RankDisp_Cmd,
    desc = FlagRSP_Locale_Help[4],
    func = function(args) FlagRSP:toggleRankDisp(); end
    }
);
tinsert( cmdTableRSP.cmds, { -- Display Guild
    cmd = FlagRSP_Locale_GuildDisp_Cmd,
    desc = FlagRSP_Locale_Help[5],
    func = function(args) FlagRSP:toggleGuildDisp(); end
    }
);
tinsert( cmdTableRSP.cmds, { -- Display Ingamename
    cmd = "ingamename", -- TODO help entry
    desc = "/rsp ingamename --> toggles the display of the used ingame name",
    show = true,
    func = function(args)
        if ( FlagRSPConfigure:GetShowUnitName() ) then
            FlagRSPConfigure:SetShowUnitName(false);
            FlagRSPStatic:PrintM("Hides the ingame name of the character.");
        else
            FlagRSPConfigure:SetShowUnitName(true);
            FlagRSPStatic:PrintM("Shows the ingame name of the character.");
        end
    end
    }
);
tinsert( cmdTableRSP.cmds, { -- Display UINames
    cmd = "uinames",
    desc = "/rsp uinames --> toggles the display of the names above the characters",
    show = true,
    func = function(args)
		FlagRSP:PrintDebug(GetCVar("UnitNamePlayer"));
		if GetCVar("UnitNameFriendlyPlayerName") == "1" then
			FlagRSPStatic:PrintM(FlagRSP_Locale_UINamesDisabled);
			SetCVar("UnitNameFriendlyPlayerName","0");
			SetCVar("UnitNameEnemyPlayerName","0");
		elseif GetCVar("UnitNameFriendlyPlayerName") == "0" then
			FlagRSPStatic:PrintM(FlagRSP_Locale_UINamesEnabled);
			SetCVar("UnitNameFriendlyPlayerName","1");
			SetCVar("UnitNameEnemyPlayerName","1");
		end
    end
    }
);
tinsert( cmdTableRSP.cmds, { -- Display InfoBox Always
    cmd = "alwaysinfobox",
    desc = "/rsp alwaysinfobox --> toogles wether the infobox is shown always or only manually",
    show = true,
    func = function(args)
		if FlagRSPConfigure:GetAlwaysShowInfoBox() then
			FlagRSPStatic:PrintM(FlagRSP_Locale_InfoBoxTradBehaviour);
			FlagRSPConfigure:SetInfoBoxState(false);
		else
			FlagRSPStatic:PrintM(FlagRSP_Locale_AlwaysShowInfoBox);
			FlagRSPConfigure:SetInfoBoxState(true);
		end
    end
    }
);
tinsert( cmdTableRSP.cmds, { -- Display Class Color
    cmd = "classcolor",
    desc = "/rsp classcolor --> toggles whether the class names are colored",
    func = function(args)
		if ( FlagRSPConfigure:GetClassColor() ) then
			FlagRSPConfigure:SetClassColor(false);
			FlagRSPStatic:PrintM("colorClassText set to false");
		else
			FlagRSPConfigure:SetClassColor(true);
			FlagRSPStatic:PrintM("colorClassText set to true");
		end
    end
    }
);
tinsert( cmdTableRSP.cmds, { -- Display Guild Rank
    cmd = "guildrank",
    desc = "/rsp guildrank --> toggles the display of the guild rank in the tooltip",
    func = function(args)
		if ( FlagRSPConfigure:GetGuildRank() ) then
			FlagRSPConfigure:SetGuildRank(false);
			FlagRSPStatic:PrintM("showGuildRank set to false");
		else
			FlagRSPConfigure:SetGuildRank(true);
			FlagRSPStatic:PrintM("showGuildRank set to true");
		end
    end
    }
);
tinsert( cmdTableRSP.cmds, { -- RSP On
    cmd = "rspon",
    desc = FlagRSP_Locale_Help[24],
    show = true,
    func = function(args) FlagRSP:enableRPTags(); end
    }
);
tinsert( cmdTableRSP.cmds, { -- RSP Off
    cmd = "rspoff",
    desc = FlagRSP_Locale_Help[25],
    show = true,
    func = function(args) FlagRSP:disableRPTags(); end
    }
);
tinsert( cmdTableRSP.cmds, { -- Display Level Color, OOO
    cmd = "coloredlevels",
    desc = "/rsp coloredlevels toggles the coloring of the level displays",
    func = function(args) FlagRSPStatic:PrintM("Coloring levels is out of order, sorry!"); end
    }
);
tinsert( cmdTableRSP.cmds, { -- Toggle Tooltip
    cmd = "toggletooltip", -- TODO Sinn?
    desc = "/rsp toggletooltip --> toggles through the tooltip styles",
    show = true,
    func = function(args)
		if ( FlagRSPConfigure:GetTooltipStyle() == "normal" ) then
			FlagRSPStatic:PrintM(FlagRSP_Locale_LightModifyTooltip);
			FlagRSPConfigure:SetTooltipStyle("light");
		elseif ( FlagRSPConfigure:GetTooltipStyle() == "light" ) then
			FlagRSPStatic:PrintM(FlagRSP_Locale_NoModifyTooltip);
			FlagRSPConfigure:SetTooltipStyle("none");
		elseif ( FlagRSPConfigure:GetTooltipStyle() == "none" ) then
			FlagRSPStatic:PrintM(FlagRSP_Locale_ModifyTooltip);
			FlagRSPConfigure:SetTooltipStyle("normal");
		end
    end
    }
);
-- tinsert( cmdTableRSP.cmds, { -- RP Mode
    -- cmd = "rpmode",
    -- desc = "/rsp rpmode [none/default/full/hard] --> Predefined RP-Settings for use",
    -- show = true,
    -- func = function(args)
        -- print("Not implemented yet, sorry!");
    -- end
    -- }
-- );
tinsert( cmdTableRSP.cmds, { -- Part: FlagRSP Config
    desc = "FlagRSP Config",
    show = true,
    }
);
tinsert( cmdTableRSP.cmds, { -- Plot Stats -- TODO Dup
    cmd = "stat",
    desc = FlagRSP_Locale_Help[22],
    show = true,
    func = function(args) FlagRSP:PlotStats(); end
    }
);
tinsert( cmdTableRSP.cmds, { -- Plot RP Config
    cmd = FlagRSP_Locale_Status_Cmd,
    desc = FlagRSP_Locale_Help[22],
    func = function(args) FlagRSP:PlotStatus(); end
    }
);
tinsert( cmdTableRSP.cmds, { -- Welcome
    cmd = "welcome",
    desc = "/rsp welcome --> Shows the welcome screen",
    func = function(args) FlagRSP:showWelcomeBox(); end
    }
);
tinsert( cmdTableRSP.cmds, { -- Tips
    cmd = "tips",
    desc = "/rsp tips --> Shows the tips",
    func = function(args) FlagRSP:showDYKBox(); end
    }
);
tinsert( cmdTableRSP.cmds, { -- Standby
    cmd = "standby", -- TODO Rework
    desc = "/rsp standby --> disables the display of rp stuff",
    func = function(args)
		-- if FlagRSPConfigure:GetStandby() then
			-- FlagRSPStatic:PrintM(FlagRSP_Locale_NoStandBy);
			-- FlagRSPConfigure:SetStandby(false);
			-- FlagRSP.standby = false;
		-- else
			-- FlagRSPStatic:PrintM(FlagRSP_Locale_StandBy);
			-- FlagRSPStatic:PrintM(FlagRSP_Locale_StandBy2);
			-- FlagRSP_LeaveChannel();
			-- FlagRSPConfigure:SetStandby(true);
			-- FlagRSP.standby = true;
		-- end
    end
    }
);
tinsert( cmdTableRSP.cmds, { -- Purge interval
    cmd = "purgeinterval",
    desc = "/rsp purgeinterval <SECONDS> --> Sets the time for flushing too old flags",
    show = true,
    func = function(args)
		FlagRSP:PrintDebug("new purge interval: " .. string.sub(msg, string.len("purgeinterval")+2, string.len(msg)));
		if string.len(msg) > string.len("purgeinterval")+1 then
			local n = tonumber(string.sub(msg, string.len("purgeinterval")+2, string.len(msg)));
			if n ~= nil then
				FlagRSPSettings.FlagPurgeInterval = n*86400;
				FlagRSP:PrintDebug("new purge interval (set): " .. FlagRSPSettings.FlagPurgeInterval);
				local msg = string.gsub(FlagRSP_Locale_PurgeInterval, "%%s", n);
				FlagRSPStatic:PrintM(msg);
			end
		else
			local msg = string.gsub(FlagRSP_Locale_PurgeInterval, "%%s", math.floor(FlagRSPSettings.FlagPurgeInterval/86400*10)/10);
			FlagRSPStatic:PrintM(msg);
		end
    end
    }
);
tinsert( cmdTableRSP.cmds, { -- Purge All
    cmd = "purge",
    desc = "/rsp purge --> Deletes ALL gathered flags of others",
    show = true,
    func = function(args)
		FlagHandler:PurgeAllFlags();
        FlagRSPProtocol:UpdateOwn();
    end
    }
);
tinsert( cmdTableRSP.cmds, { -- ??? edit friendlist something, OOO
    cmd = "edit", -- TODO help entry
    desc = "/rsp edit --> no idea",
    func = function(args) FlagRSPStatic:PrintM("Friendlist-command \"edit\" is out of order, sorry!"); end
    }
);
tinsert( cmdTableRSP.cmds, { -- Reset Button
    cmd = "resetbutton",
    desc = FlagRSP_Locale_Help[26],
    show = true,
    func = function(args) FlagRSPConfigure:SetInfoBoxButtonCoords(-1, -1); end
    }
);
tinsert( cmdTableRSP.cmds, { -- Reset InfoBox
    cmd = "resetinfobox",
    desc = FlagRSP_Locale_Help[27],
    show = true,
    func = function(args) FlagRSPInfo:ResetPosition(); end
    }
);
tinsert( cmdTableRSP.cmds, { -- Reset InfoBox
    cmd = "showhidden",
    desc = "/rsp showhidden --> Prints ALL (hidden) commands",
    func = function(args)
        if cmdTableRSP.printall then
            cmdTableRSP.printall = nil;
        else
            cmdTableRSP.printall = true;
        end
    end
    }
);
tinsert( cmdTableRSP.cmds, { -- Part: Debug
    desc = "FlagRSP Debug",
    }
);
tinsert( cmdTableRSP.cmds, { -- Debug Print
    cmd = "debug",
    desc = "/rsp debug --> toggles the print for debug purposes",
    func = function(args)
		if flagRSP_Debug then
			FlagRSPStatic:PrintM("Left debug mode.",1.0, 1.0, 0.0);
			flagRSP_Debug = false;
		else
			FlagRSPStatic:PrintM("Entered debug mode.",1.0, 1.0, 0.0);
			flagRSP_Debug = true;
		end
    end
    }
);
tinsert( cmdTableRSP.cmds, { -- Debug Save
    cmd = "debugsave",
    desc = "/rsp debugsave --> saves some data for debugging",
    func = function(args)
		if flagRSP_DebugSave then
			FlagRSPStatic:PrintM("Left debug saving mode.",1.0, 1.0, 0.0);
			flagRSP_DebugSave = false;
		else
			FlagRSPStatic:PrintM("Entered debug saving mode.",1.0, 1.0, 0.0);
			flagRSP_DebugSave = true;
		end
    end
    }
);






SLASH_FRIENDLISTCOMMAND1 = "/fl";
SLASH_FRIENDLISTCOMMAND2 = "/friendlist";
SlashCmdList["FRIENDLISTCOMMAND"] = FRIENDLIST_SlashHandler;



SLASH_ADD1 = "/add";
SlashCmdList["ADD"] = addfriend_Msg;