

FlagRSPStatic = {}; -- static functions, no instance variables used


--[[ Returns hex number as string with minimum string length len for positive integer num.

- local hexString = FlagRSPStatic:GetHexString(num)

]]--
function FlagRSPStatic:GetHexString( num, len )
	local digits = "0123456789ABCDEF";
	local hexnum = "";
	local intdigit;

	while num > 0 do
		num = math.floor(num);
		intdigit = math.fmod(num, 16);
		num = math.floor(num/16);

		hexnum = string.sub(digits, (intdigit+1), (intdigit+1)) .. hexnum;
	end

	while string.len(hexnum) < len do
		hexnum = "0" .. hexnum;
	end

	return hexnum;
end


--[[ Takes in three decimal color values and outputs one hex string.
   Mostly just to save typing space, however this function will be used
   more often.

- local hex = FlagRSPStatic:GetHex(red, green, blue)

]]--
function FlagRSPStatic:GetHex( red, green, blue )
	local hexstring = "";
	
	hexstring = self:GetHexString(red*255, 2) .. self:GetHexString(green*255, 2) .. self:GetHexString(blue*255, 2);
	
	return hexstring;
end


--[[ Prints message msg in <frame>

- FlagRSPStatic:Print(msg)

]]--
function FlagRSPStatic:Print( msg, frame )
	if frame == nil then
		frame = DEFAULT_CHAT_FRAME;
	end

	frame:AddMessage(msg,1,1,0);
end


--[[ Prints message msg in flagRSP style.

- FlagRSPStatic:PrintM(msg)

]]--
function FlagRSPStatic:PrintM( msg )
	DEFAULT_CHAT_FRAME:AddMessage("|CFF" .. self:GetHex(1.0, 1.0, 0.5) .. "<flagRSP>|r " .. tostring(msg),1,1,1);
end


--[[ Prints error message msg in flagRSP style.

- FlagRSPStatic:PrintE(msg)

]]--
function FlagRSPStatic:PrintE( msg )
	DEFAULT_CHAT_FRAME:AddMessage("|CFF" .. self:GetHex(1.0, 1.0, 0.5) .. "<flagRSP>|r|CFF" .. self:GetHex(1.0, 0.0, 0.0) .. "<ERROR>|r" .. msg,1,1,1);
end


--[[ Prints assertion message msg in flagRSP style.

- FlagRSPStatic:PrintA(msg)

]]--
function FlagRSPStatic:PrintA( number )
	FlagRSPStatic:PrintM("|Cffff0000ASSERTION #" .. number .. " FAILED!|r Please contact flagRSP developer!");
end


--[[ Prints debug message msg

- FlagRSPStatic:PrintD(msg)

--]]
function FlagRSPStatic:PrintD( msg )
    DEFAULT_CHAT_FRAME:AddMessage("|CFF" .. self:GetHex(1.0, 1.0, 0.5) .. "<flagRSP> DEBUG:|r\n " .. msg,1,1,1);
end


--[[ Removes colour codes from string <s>.

- FlagRSPStatic:RemoveColourCode(s)

]]--
function FlagRSPStatic:RemoveColourCode( s ) -- from TooltipHandler
	--[0-9,a-f][0-9,a-f][0-9,a-f][0-9,a-f][0-9,a-f][0-9,a-f][0-9,a-f][0-9,a-f]
	local sNew = s;

	if sNew ~= nil then
		while string.find(sNew, "|[c,C][0-9,a-f,A-F][0-9,a-f,A-F][0-9,a-f,A-F][0-9,a-f,A-F][0-9,a-f,A-F][0-9,a-f,A-F][0-9,a-f,A-F][0-9,a-f,A-F]") ~= nil do
			sNew = string.gsub(sNew,"|[c,C][0-9,a-f,A-F][0-9,a-f,A-F][0-9,a-f,A-F][0-9,a-f,A-F][0-9,a-f,A-F][0-9,a-f,A-F][0-9,a-f,A-F][0-9,a-f,A-F]", "");
		end
		while string.find(sNew, "|[r,R]") ~= nil do
			sNew = string.gsub(sNew,"|[r,R]", "");
		end
	end

	return sNew;
end

function FlagRSPStatic:GetRPFlagText( rpflag, color )
	rpflag = rpflag or 0;
	
	local text = "";
	if tonumber(rpflag) then
		if rpflag == 1 then
			text = FlagRSP_Locale_RP;
		elseif rpflag == 2 then
			text = FlagRSP_Locale_RP2;
		elseif rpflag == 3 then
			text = FlagRSP_Locale_RP3;
		elseif rpflag == 4 then
			text = FlagRSP_Locale_RP4;
		end
	else
		text = rpflag;
	end
	-- if text ~= "" then
		-- text = "<" .. text .. ">";
	-- end

	
	if text ~= "" then
		if ( type(color) == string and strlen(color) == 8) then
			text = "|c" .. color .. text .. "|r";
		elseif ( type(color) == string and strlen(color) == 6 ) then
			text = "|cFF" .. color .. text .. "|r";
		elseif ( color and text ~= "") then
			text = "|cFF" .. FlagRSPStatic:GetHex(1.0, 1.0, 0.5) .. text .. "|r";
		end
	end
	
	return text or "";
end

function FlagRSPStatic:GetCharStateText( charstatus, color )
	charstatus = charstatus or 0;
	
	local text = ""
	if tonumber(charstatus) then
		if charstatus == 1 then -- ooc
			text = FlagRSP_Locale_OOC;
		elseif charstatus == 2 then  -- ic
			text = FlagRSP_Locale_IC;
		elseif charstatus == 3 then -- ffa-ic
			text = FlagRSP_Locale_FFAIC;
		elseif charstatus == 4 then --st
			text = FlagRSP_Locale_ST;
		end
	else
		if cstatus == "ooc" then
			text = FlagRSP_Locale_OOC;
		elseif cstatus == "ic" then
			text = FlagRSP_Locale_IC;
		elseif cstatus == "ffa-ic" then
			text = FlagRSP_Locale_FFAIC;
		elseif cstatus == "st" then
			text = FlagRSP_Locale_ST;
		-- else
			-- text = charstatus;
		end
	end
	-- if text ~= "" then
		-- text = "<" .. text .. ">";
	-- end

	if text ~= "" then
		if ( type(color) == string and strlen(color) == 8) then
			text = "|c" .. color .. text .. "|r";
		elseif ( type(color) == string and strlen(color) == 6 ) then
			text = "|cFF" .. color .. text .. "|r";
		elseif ( color and text ~= "") then
			text = "|cFF" .. FlagRSPStatic:GetHex(1.0, 1.0, 0.5) .. text .. "|r";
		end
	end
	
	return text or "";
end


function FlagRSPStatic:transformCharFlag(id) -- TODO only used in Tooltiphandler, move to static
    if ( id == "1" or id == 1 ) then -- ooc
        return "ooc";
    elseif ( id == "2" or id == 2 ) then -- ic
        return "ic";
    elseif ( id == "3" or id == 3 ) then -- ffa-ic
        return "ffa-ic";
    elseif ( id == "4" or id == 4 ) then -- st
        return "st";
    else -- none
        return "";
    end
end

function FlagRSPStatic:ColorString( text, color )
	s = "";
	if type(color) == string and strlen(color) == 8 then
		s = "|c" .. color .. text .. "|r";
	elseif type(color) == string and strlen(color) == 6 then
		s = "|cFF" .. color .. text .. "|r";
	elseif type(color) == table and table.getn(color) == 3 then
		s = "|cFF" .. FlagRSPStatic:GetHex( color[1], color[2], color[3] );
		s = s .. text;
		s = s .. "|r";
	else
		s = text;
	end
	return s;
end