FlagHandler = { };

FlagList2 = { };


--[[ Returns whether or not a character has some form of flag.
--  local boolean = FlagHandler:IsSetFlag(ingameName, realm)
]]--
function FlagHandler:IsSetFlag( ingameName, realm )
    realm = self:GetRealm(realm);
    
    if not FlagHandler:IsSetEntry( ingameName, realm ) then
        return false;
    end

	if ( FlagList2[realm][ingameName] ~= nil and FlagList2[realm][ingameName]["Desc"] ~= nil ) then
		return true;
	else
		return false;
	end
end


--[[ Returns whether or not a character is in the flag list
--  local boolean = FlagHandler:IsSetEntry(ingameName, realm)
]]--
function FlagHandler:IsSetEntry( ingameName, realm )
    realm = self:GetRealm(realm);
    if ( FlagList2 ~= nil and FlagList2[realm] ~= nil and FlagList2[realm][ingameName] ~= nil ) then
		return true;
	else
		return false;
	end
end


--[[ Prepares the realm name for use in FlagList, if no realm set, it uses the own realm of the player

]]--
function FlagHandler:GetRealm( realm )
    if ( realm == nil or realm == "" ) then
        realm = FlagRSP.rName;
    end

    realm = gsub(realm, " ", "");
    return realm;
end


--[[ Creates a flag entry if none exists

--  FlagHandler:CreateEntry(ingameName, realm)

-- If an entry at <name> doesn't exist, this will create the necessary fields for it.
-- It will not erase an old entry or any fields it does not have.

]]--
function FlagHandler:CreateEntry( ingameName, realm )
    realm = self:GetRealm(realm);

	if ( FlagList2[realm] == nil ) then
		FlagList2[realm] = {};
	end
	
	if ( FlagList2[realm][ingameName] == nil ) then
		FlagList2[realm][ingameName] = {};
	end
end


--[[ Add flag <flag> with value <value> for player <name> on <realm> (withoud spaces)

FlagHandler:AddFlag()

]]--
function FlagHandler:AddFlag( flag, value, ingameName, revision, realm )
    realm = self:GetRealm(realm);

	if flag == nil or flag == "" then
		return;
	end

    if revision == nil then
        revision = -1;
    end

    FlagHandler:CreateEntry(ingameName, realm);

    local isSet = false;
	if ( flag == "Fullname" or flag == "Title" or flag == "FlagAddon" or flag == "Desc" 
            or flag == "Surname" or flag == "Name" or flag == "Middle" 
            or flag == "Current" ) then -- strings
		FlagList2[realm][ingameName][flag] = value;
        isSet = true;

    elseif ( flag == "CharFlag" or flag == "RPFlag" ) then -- numbers, integer
        FlagList2[realm][ingameName][flag] = tonumber(value);
        isSet = true;

	end

    if ( isSet ) then
        FlagList2[realm][ingameName].timeStamp = time();
        FlagList2[realm][ingameName].faction = UnitFactionGroup("player");

        -- Saves the version of the field
        if ( FlagList2[realm][ingameName].ver == nil ) then
            FlagList2[realm][ingameName].ver = {};
        end
        FlagList2[realm][ingameName].ver[flag] = revision;
    end
end


--[[ Get flag <flag> for player <ingameName> on <realm>

FlagHandler:GetFlag()

]]--
function FlagHandler:GetFlag( flag, ingameName, realm )
	local value = "";
    realm = self:GetRealm(realm);


	if ( FlagList2[realm] ~= nil and FlagList2[realm][ingameName] ~= nil and FlagList2[realm][ingameName][flag] ~= nil ) then
		value = FlagList2[realm][ingameName][flag];
	end

	if ( value == nil ) then
		value = "";
	end

	return value;
end


--[[ Get revision of <flag> for player <ingameName> on <realm>

FlagHandler:GetFlagRev()

]]--
function FlagHandler:GetFlagRev( flag, ingameName, realm )
	local rev = "";
    --local realm = FlagRSP.rName;
    realm = self:GetRealm(realm);

	if ( FlagList2[realm] ~= nil and FlagList2[realm][ingameName] ~= nil and FlagList2[realm][ingameName][flag] ~= nil ) then
		rev = FlagList2[realm][ingameName]["ver"][flag];
	end

	if ( rev == nil ) then
		rev = "";
	end

	return rev;
end


--[[ Purges old flags that haven't been seen for quite some time.

FlagHandler:PurgeFlags()

]]--
function FlagHandler:PurgeFlags()

	-- oldest timestamp we accept.
	local delTime = time() - FlagRSPSettings.FlagPurgeInterval;
	local entriesDeleted = 0;
	local entriesDeletedRealm = 0;

	for realm, list in pairs(FlagList2) do
		-- e.g. list is FlagList["RPFlag"]

		entriesDeletedRealm = 0;

		for name, entry in pairs(list) do
			if entry.timeStamp == nil then
				list[name] = nil;
				entriesDeleted = entriesDeleted + 1;
				entriesDeletedRealm = entriesDeletedRealm + 1;
			elseif entry.timeStamp < delTime then
				list[name] = nil;
				entriesDeleted = entriesDeleted + 1;
				entriesDeletedRealm = entriesDeletedRealm + 1;
			end
		end

	end

	if entriesDeleted > 0 then
		local msg = string.gsub(FlagRSP_Locale_EntriesPurged, "%%s", entriesDeleted);
		FlagRSPStatic:PrintM(msg);
	end
end


--[[ Purges ALL saved flags.

FlagHandler:PurgeAllFlags()

]]--
function FlagHandler:PurgeAllFlags()

	local entriesDeleted, flags = self:GetStats();

	FlagList2 = nil;
	FlagList2 = {};

	local msg = string.gsub(FlagRSP_Locale_EntriesPurged, "%%s", entriesDeleted);
	FlagRSPStatic:PrintM(msg);
end


--[[ Returns some statistics about saved flags.
--  Return values:
--      numEntries: number
--      flags: table[0-4] for each type of flag (0 to 4), containing the number respectively
]]--
function FlagHandler:GetStats()
	local numEntries = 0;
	local flags = {};
	local numEntriesRealm = 0;

	for i = 0, 4 do
		flags[i] = 0;
	end

	for realm, list in pairs(FlagList2) do
		numEntriesRealm = 0;

		for name, entry in pairs(list) do
			numEntries = numEntries + 1;
			numEntriesRealm = numEntriesRealm + 1;
			
			if entry.RPFlag ~= nil then
				flags[entry.RPFlag] = flags[entry.RPFlag] + 1;
			end
		end
	end

	return numEntries, flags;
end

