--[[ ==== Protocol handler =============================================================================== ]]--

FlagRSPProtocol = {
    timeForOnline = 300; -- 5 min
};

local isAlive = false;

function FlagRSPProtocol:IsAlive()
    return isAlive;
end

--[[ Actions on addon load event

]]--
function FlagRSPProtocol:OnLoad()
    if self.isAlive then
        -- FlagRSPStatic:PrintD("Protocol isAlive");
        local version = FlagRSP.verMajor .. "." .. FlagRSP.verMinor .. "." .. FlagRSP.verPatch;
        --msp.my.VA = "flagRSP/".. tostring(GetAddOnMetadata("flagRSP |cFF029B78[MoP]|r", "Version"));
        
        msp.my.VA = "flagRSP/"..version or "";
        msp.my.GU = UnitGUID("player");
        msp.my.GS = tostring( UnitSex("player"));
        msp.my.GC = select( 2, UnitClass("player"));
        msp.my.GR = select( 2, UnitRace("player"));
        
        table.insert( msp.callback.received, FlagRSPProtocol.CallbackMSP);
        
        msp:Update();
    else
        -- FlagRSPStatic:PrintD("Protocol dead");
    end
end


--[[ Actions on player logout event

]]--
function FlagRSPProtocol:OnLogout()
    -- Saving msp data
    FlagRSPData.msp = {};
    FlagRSPData.msp.my = {};
    FlagRSPData.msp.my = msp.my;
    FlagRSPData.msp.myver = {};
    FlagRSPData.msp.myver = msp.myver;
end


--[[ Request to relative unitID
    - unit = "mouseover", "target"
    - fields = MSP based field names, one string ("DE") or in a table { "DE", "NA" }
]]--
function FlagRSPProtocol:Request( unit, fields )

    local request = false;
    local ok = false;

    if ( UnitExists(unit) and UnitPlayerControlled(unit) and not (UnitIsUnit(unit,"player") == 1)) then
        ok = true;
    elseif strfind(unit,"^party") or strfind(unit, "^raid") or strfind(unit, "^focus") then
        ok = true;
    end
    
    if ok then
        local unitName, unitRealm = UnitName(unit);
        local reqName = "";
        if ( unitRealm == nil or unitRealm == "" )then
            reqName = unitName;
        elseif ( unitRealm ~= nil and unitRealm ~= "" ) then
            reqName = unitName .. "-" .. unitRealm;
        end

        local fieldTable;
        if ( fields == "ott" ) then -- Tooltip data
            fieldTable = self.mspSupportedTTFields;
        elseif ( fields == "oib" ) then -- Info box data
            fieldTable = self.mspSupportedIBFields;
        elseif ( fields == "ofb" ) then -- Friend box data
            fieldTable = self.mspSupportedIBFields;
        else
            fieldTable = fields or self.mspSupportedTTFields;
        end
        request = msp:Request(reqName, fieldTable);
    end

    return request;
end


--[[ Request direct to playerID
    - name = name of a player, realm foreigners are noted as "player-realm"
    - fields = table with fields to request
]]--
function FlagRSPProtocol:RequestDirect( name , fields )
    local request = false;

    request = msp:Request(name, fields);
    
    return request;
end


--[[ Update Flag, Tooltip
]]--
function FlagRSPProtocol:Update( unitType, unit, request )
    if ( request ) then
        local unitName, unitRealm = UnitName(unit);
        local reqName = "";
        if ( unitType == "callback" ) then
            reqName = unit;
        elseif ( unitType == "isonline" ) then
            reqName = unit;
        elseif ( unitRealm ~= nil and unitRealm ~= "" ) then
            reqName = tostring(unitName) .. "-" .. tostring(unitRealm);
        else
            reqName = unitName;
        end
        FlagRSPProtocol:UpdateFlagList2( reqName, msp.char[reqName].field, msp.char[reqName].ver, "libmsp", unitRealm);
        FlagRSP:UpdateTooltip(true);
    end
end


-- UpdateOwn
function FlagRSPProtocol:UpdateOwn()
    
    if ( isAlive ) then 
        -- Update MSP Data
        msp.my["NA"] = FlagRSPConfigure:GetFullname();
        msp.my["NT"] = FlagRSPConfigure:GetTitle();
        msp.my["DE"] = FlagRSPConfigure:GetDescription();
        msp.my["FR"] = tostring(FlagRSPConfigure:GetRPFlag());
        msp.my["FC"] = tostring(FlagRSPConfigure:GetCharacterStatus());
        msp:Update();
    end

    -- Update FlagList2
    local pName, pRealm = UnitName("player");
    
    FlagRSPProtocol:UpdateFlagList2( pName, msp.my, msp.myver, "libmspintern", pRealm);

    -- Update Tooltip, InfoBoxes
    -- FlagRSP:UpdateTooltip();
end


function FlagRSPProtocol:IsSupported( name )
    if ( msp.char[name] == nil ) then
        return false;
    end
    return msp.char[name].supported;
end


--[[ Checks if "ingameName" is online, uses protocol for check
    Returns
        - 1 if online
        - -1 if offline
        - 0 if offline and no information on this guy (maybe protocol not supported)
]]--
function FlagRSPProtocol:CheckIsOnline( ingameName, realm )
    if ingameName == nil then return; end
    
    local isOnline = 0;
    realm = FlagHandler:GetRealm(realm);

    -- if ( ingameName ~= nil and FlagList2[realm][ingameName] ~= nil ) then
    if ( ingameName ~= nil and FlagHandler:IsSetEntry( ingameName, realm ) ) then
        local lastFlagTime = FlagHandler:GetFlag("timeStamp", ingameName, nil);
        local now = time();

        if ( lastFlagTime ~= nil ) then -- Entry exists
            local lastSeen = now - tonumber(lastFlagTime);
            if ( lastSeen <= self.timeForOnline ) then
                isOnline = 1;
            else
                isOnline = -1;
            end
        end
        if ( isOnline ~= 1 ) then -- Else ask for entry
            local request = FlagRSPProtocol:RequestDirect( ingameName , self.mspSupportedTTFields );
            FlagRSPProtocol:Update("isonline", ingameName, request)
        end
    end


    return isOnline;
end


function FlagRSPProtocol:UpdateFlagList2( ingameName, fields, revisions, protocol, realm )
    if ( protocol == nil or protocol == "libmsp" or protocol == "libmspintern") then
        local c, r = fields, revisions;
        if (protocol == "libmsp") then
            -- Check if data supported
            if ( not FlagRSPProtocol:IsSupported( ingameName ) ) then
                return;
            end
        end

        -- Full name
        if ( fields["NA"] ~= nil ) then
            FlagHandler:AddFlag("Fullname", fields["NA"], ingameName, revisions["NA"], realm);
        end

        -- Title
        if ( fields["NT"] ~= nil ) then
            FlagHandler:AddFlag("Title", fields["NT"], ingameName, revisions["NT"], realm);
        end

        -- Flag RP
        if ( fields["FR"] ~= nil ) then
            FlagHandler:AddFlag("RPFlag", tonumber(fields["FR"]), ingameName, revisions["FR"], realm);
        end

        -- Flag Character
        if ( fields["FC"] ~= nil ) then
            FlagHandler:AddFlag("CharFlag", fields["FC"], ingameName, revisions["FC"], realm);
        end

        -- Used Flagaddon
        if ( fields["VA"] ~= nil ) then
            FlagHandler:AddFlag("FlagAddon", fields["VA"], ingameName, revisions["VA"], realm);
            -- Check FlagRSP Version
            local name, ver,_ = strsplit("/",fields["VA"],3);
            if ( name == "flagRSP" ) then
                FlagRSP:checkVersion(ver);
            end
        end
        
        -- Currently
        if ( fields["CU"] ~= nil ) then
            FlagHandler:AddFlag("Current", fields["CU"], ingameName, revisions["CU"], realm);
        end        

        -- Desciption
        if ( fields["DE"] ~= nil ) then
            FlagHandler:AddFlag("Desc", fields["DE"], ingameName, revisions["DE"], realm);
        end

        -- Versions are updated in FlagHandler:addFlag
    end
end



--[[ ==== Library support for LibMSP ===================================================================== ]]--
-- Detect any other MSP AddOn and bail out in case of conflict, based on Etarna, http://moonshyne.org/msp/

local FlagRSP_Locale_MSP_CONFLICT = "ERROR: You can only use one MSP AddOn at once, but you have both flagRSP and %s loaded.\n\nAll MSP AddOns can communicate with each other, but please do not try to use more than one at once as conflicts might arise.";
local FlagRSP_Locale_MSP_CONFLICTADDON = "another MSP AddOn";
if _G.msp_RPAddOn or _G.mrp then
	StaticPopupDialogs[ "FLAGRSP_MSP_CONFLICT" ] = {
        preferredIndex = 3,
		text = format( FlagRSP_Locale_MSP_CONFLICT, tostring(_G.msp_RPAddOn) or FlagRSP_Locale_MSP_CONFLICTADDON ),
		button1 = OKAY or "OK",
		whileDead = true,
		timeout = 0,
	};
	StaticPopup_Show( "FLAGRSP_MSP_CONFLICT" );
    
	-- return
    isAlive = false;
else
    _G.msp_RPAddOn = "flagRSP";
    isAlive = true;
end 

FlagRSPProtocol.mspSupportedTTFields = { "NA", "NT", "FR", "FC", "VA", "DE", "CU" }; -- Tooltip
FlagRSPProtocol.mspSupportedIBFields = { "NA", "NT", "FR", "FC", "VA", "DE", "CU" }; -- InfoBox


function FlagRSPProtocol.CallbackMSP( ingameID )
    FlagRSPProtocol:Update("callback", ingameID, true);
end


function FlagRSPProtocol:LoadMsp()
    -- FlagRSPData must be available!
    if (isAlive and FlagRSPData ~= nil ) then
        msp.my.NA = FlagRSPData.Fullname;
        msp.my.NT = FlagRSPData.Title;
        msp.my.DE = FlagRSPData.CharDesc;
        msp.my.FR = FlagRSPData.RPFlag;
        msp.my.FC = FlagRSPData.CharStatus;

        msp:Update();

        if(FlagRSPData.msp ~= nil ) then
            if ( FlagRSPData.msp.myver ~= nil ) then
                msp.myver = FlagRSPData.msp.myver;
            end
        end
    end
end