--[[

settings.lua

- flagRSP setting file. Keeps default values and methods to handle settings.

]]--


-- Public variables
FlagRSPConfigure = {
	loaded = false;
	initialized = false;
};

-- Saved variables
FlagRSPSettings = {
    FlagPurgeInterval = 1209600, -- 14 days
};

FlagRSPData = nil;

-- Constant variables
-- FlagRSPConfigure.FL_SORTORDER_X = "";

-- FlagRSPConfigure.GUILDDISPLAY_ALL = "all"; -- 1
-- FlagRSPConfigure.GUILDDISPLAY_KNOWN = "known"; -- 0
-- FlagRSPConfigure.GUILDDISPLAY_NONE = "none"; --  -1

-- FlagRSPConfigure.TOOLTIPMODIFY_NONE = "none";
-- FlagRSPConfigure.TOOLTIPMODIFY_LIGHT = "light";
-- FlagRSPConfigure.TOOLTIPMODIFY_RP = "normal";
-- FlagRSPConfigure.LEVELTEXT_ = ;
-- FlagRSPConfigure.GUILDSHOW_ = ;
-- FlagRSPConfigure.LEVELCHANGE_ = ;
-- FlagRSPConfigure.LEVELDISPLAY_COLOR = "color";
-- FlagRSPConfigure.LEVELDISPLAY_RELATIVE = "relative";
-- FlagRSPConfigure.LEVELDISPLAY_NONE = "none";

--[[

FlagRSPConfigure:Initialize()

-- Makes sure settings are loaded and things are ready to run.

]]--

function FlagRSPConfigure:Initialize()
	local player = UnitName("player");
	local realm = GetCVar("realmName");
	local init = true;
	
	if ( player == nil or realm == nil or player == UNKNOWNOBJECT or player == UNKNOWNBEING ) then
		init = false;
	end
	
	if ( init ) then
		self.initialized = true;
		return player, realm;
	end
end

--[[

FlagRSPConfigure:IsInitialized()

- check if game is initialized.

]]--
function FlagRSPConfigure:IsInitialized()
	return self.initialized;
end

--[[

FlagRSPConfigure:InitializeSettings()

- initialize settings for current player.

]]--
function FlagRSPConfigure:InitializeSettings()
	if not self:IsInitialized() then
		return "";
	end
   
   
	if self.loaded ~= true and FlagRSPData == nil then
    
        FlagRSPConfigure:defaultSettings( true );
        FlagRSPConfigure:defaultFlag( true );

		-- self:loadCustoms();

		-- some stuff...
		FlagRSPInfo.maxDesc = math.ceil(FlagRSPInfo.maxDescChars/FlagRSPInfo.charPerPost);
      
		self.loaded = true;

		-- Abstract this out into a function that runs on load.
		if FlagRSP ~= nil and Friendlist ~= nil then
			if FlagRSPData.welcomeBoxShown == nil then
				FlagRSPData.welcomeBoxShown = {};
	    
				FlagRSPData.welcomeBoxShown.version = FlagRSP.versionString;
				FlagRSPData.welcomeBoxShown.shown = true;
	    
				FlagRSP:showWelcomeBox(true);
			elseif FlagRSPData.welcomeBoxShown.version ~= FlagRSP.versionString then
				FlagRSPData.welcomeBoxShown.version = FlagRSP.versionString;
				FlagRSPData.welcomeBoxShown.shown = true;

				FlagRSP:showWelcomeBox(false);
			end
		end
		
		-- TODO This is hacked in. . . Take it out before release.
		if ( FlagRSPInfoBoxList[FlagRSP.rName] == nil ) then
			FlagRSPInfoBoxList[FlagRSP.rName] = { };
		end
		if ( FlagRSPInfoBoxList[FlagRSP.rName][FlagRSP.pName] == nil ) then
			FlagRSPInfoBoxList[FlagRSP.rName][FlagRSP.pName] = { };
		end

    elseif FlagRSPData ~= nil then
        if (FlagRSPConfigure:GetFullname() == "" ) then -- builds fullname if not available
            local newFullname = "";
            local playerName = UnitName("player");
            newFullname = FlagRSPConfigure:GetName() .. " " .. playerName .. " " .. FlagRSPConfigure:GetSurname();
            newFullname = strtrim(newFullname);
            FlagRSPConfigure:SetFullname(newFullname);
            FlagRSPProtocol:UpdateOwn();
        end
	end
end

--[[ Resets the settings to default
    - reset == true deletes all config and replaces it with the default
    - reset == false keeps some selected values
]]--
function FlagRSPConfigure:defaultSettings( reset )
    if ( reset == nil ) then
        reset = false;
    end
    if ( reset ) then
        -- TODO Backup flagdata!
        -- TODO Use setters for defaults
		FlagRSPData = { };
        
        FlagRSPData.version = {
            release = 1,
            major = 2,
            minor = 0,
            atleast = true,
        };
		
		FlagRSPData.InfoBoxX = 0;
		FlagRSPData.InfoBoxY = 400;
		FlagRSPData.InfoBoxAlphaBackdrop = 0.3;
		FlagRSPData.displayInfoBox = true;
		FlagRSPData.InfoBoxWidth = 300;
		FlagRSPData.InfoBoxTextSize = 12;
		FlagRSPData.InfoBoxExpandUpwards = true;
		FlagRSPData.InfoBoxLocked = false;
		FlagRSPData.InfoBoxAutoPopUp = true;
		FlagRSPData.buttonPosition = 288;
		FlagRSPData.showMiniMapButtonNew = true;

		-- New options that are saved per character and per realm.
		FlagRSPData.nameChange = false;
		FlagRSPData.levelChange = false; -- TODO maybe remove
		FlagRSPData.showRanks = true;
        FlagRSPData.showUnitName = true;
		FlagRSPData.showGuilds = -1;
        FlagRSPData.showUnitName = true;

		-- Added tooltip options for class and level coloring.
		FlagRSPData.colorLevelText = false;
		FlagRSPData.colorClassText = false;
		FlagRSPData.showGuildRank = false;

		-- how many seconds are flags saved (default 14 days).
		if FlagRSPSettings.FlagPurgeInterval == nil then
			FlagRSPSettings.FlagPurgeInterval = 1209600;
		end

		-- FlagRSPData.SkinnableFancy = false;
        
        FlagRSPData.descBoxWarningSeen = false;
        FlagRSPData.nameBoxWarningSeen = false;

		FlagRSPData.ShowVersionNotification = true;
		FlagRSPData.ShowTips = true;

		FlagRSPData.showFriendlistEntryBox = true;
		FlagRSPData.FriendlistEntryBoxLocked = false;

		FlagRSPData.FriendlistSortOrder = "FLSorting_onlineCompSurname";

		FlagRSPData.InfoBoxButtonX = -1;
		FlagRSPData.InfoBoxButtonY = -1;

		FlagRSPData.alwaysShowInfoBox = false;

		FlagRSPData.modifyTooltip = "normal";

		FlagRSPData.numOnlineList = {};
		FlagRSPData.numOnlineList.position = 1;
		FlagRSPData.numOnlineList[1] = 0;
		FlagRSPData.numOnlineList[2] = 0;
		FlagRSPData.numOnlineList[3] = 0;
		FlagRSPData.numOnlineList[4] = 0;
		FlagRSPData.numOnlineList[5] = 0;
		FlagRSPData.numOnlineList[6] = 0;
		FlagRSPData.numOnlineList[7] = 0;
		FlagRSPData.numOnlineList[8] = 0;
		FlagRSPData.numOnlineList[9] = 0;
		FlagRSPData.numOnlineList[10] = 0;

		FlagRSPData.standby = false;
    end
end

--[[ Resets the flag settings to default
    - reset == true deletes the whole flag info and replaces it with the default
    - reset == false keeps some selected values
]]--
function FlagRSPConfigure:defaultFlag( reset )
    if reset == nil then
        reset = false;
    end
    if ( reset ) then
		FlagRSPData.CharDesc = "";
		FlagRSPData.CharDescRev = 0;

		FlagRSPData.Name = "";
		FlagRSPData.MiddleName = "";
		FlagRSPData.Surname = "";
		FlagRSPData.Fullname = "";
		FlagRSPData.Title = "";
        
		FlagRSPData.RPFlag = 0;
		FlagRSPData.CharStatus = 0;
    else -- TODO initialize/Reset flag data with using setters of flagrspconfigure
		FlagRSPData.CharDesc = tostring(FlagRSPData.CharDesc) or "";
		FlagRSPData.CharDescRev = tonumber(FlagRSPData.CharDescRev) or 0;

		FlagRSPData.Name = tostring(FlagRSPData.Name) or "";
		FlagRSPData.MiddleName = tostring(FlagRSPData.MiddleName) or "";
		FlagRSPData.Surname = tostring(FlagRSPData.Surname) or "";
		FlagRSPData.Fullname = tostring(FlagRSPData.Fullname) or "";
		FlagRSPData.Title = tostring(FlagRSPData.Title) or "";
        
		FlagRSPData.RPFlag = tonumber(FlagRSPData.RPFlag) or 0;
		FlagRSPData.CharStatus = tonumber(FlagRSPData.CharStatus) or 0;
    end
end


--[[ === Character Roleplaying Settings ===]]--

--[[

FlagRSPConfigure:GetRPFlag()

-- Returns the current RP flag.

]]--

function FlagRSPConfigure:GetRPFlag()
    if (type(FlagRSPData.RPFlag) ~= "number") then
        return 0;
    end
	return tonumber(FlagRSPData.RPFlag) or 0;
end

--[[ Sets the value of the RP Flag

FlagRSPConfigure:SetRPFlag(state)

-- Sets the current RP flag to state.
-- State is an integer, 0 through 4.
-- 0 => No Roleplaying Flag
-- 1 => Normal Roleplayer
-- 2 => Casual Roleplayer
-- 3 => Fulltime Roleplayer
-- 4 => Beginning Roleplayer

]]--
function FlagRSPConfigure:SetRPFlag(state)
    if tonumber(state) ~= nil and state >= 0 and state <= 4 then
        FlagRSPData.RPFlag = state;
    else
        FlagRSPData.RPFlag = 0;
    end
end

--[[

FlagRSPConfigure:GetOldRPFlag()

-- This returns the previous RP flag when RP is enabled after being disabled.

]]--

function FlagRSPConfigure:GetOldRPFlag()
	return FlagRSPData.OldRPFlag or 0;
end

--[[

FlagRSPConfigure:SetOldRPFlag()

-- This stores the previous RP flag when RP is disabled.

]]--

function FlagRSPConfigure:SetOldRPFlag(state)
    if tonumber(state) ~= nil and state >= 0 and state <= 4 then
        FlagRSPData.OldRPFlag = state;
    else
        FlagRSPData.OldRPFlag = 0;
    end
end

--[[

FlagRSPConfigure:GetCharacterStatus()

-- Returns the player's character status.

]]--

function FlagRSPConfigure:GetCharacterStatus()
    if (type(FlagRSPData.CharStatus) ~= "number") then
        return 0;
    end
	return FlagRSPData.CharStatus or 0;
end

--[[

FlagRSPConfigure:SetCharacterStatus(state)

-- Sets the character status to possible states:
-- 1, ooc => Out of character
-- 2, ic => In character
-- 3, ffa-ic => In character, looking for contact
-- 4, st => Storyteller
-- 0, none => No flag

]]--

function FlagRSPConfigure:SetCharacterStatus(state)
    if tonumber(state) ~= nil and state >= 0 and state <= 4 then
        FlagRSPData.CharStatus = state;
    else
        FlagRSPData.CharStatus = 0;
    end
end

--[[

FlagRSPConfigure:GetSurname()

-- Returns the player's surname.

]]--

function FlagRSPConfigure:GetSurname()
	return FlagRSPData.Surname or "";
end

--[[

FlagRSPConfigure:SetSurname(name)

-- Sets the player's surname to name.

]]--

function FlagRSPConfigure:SetSurname(name)
	FlagRSPData.Surname = name;
end

function FlagRSPConfigure:GetFullname()
    return FlagRSPData.Fullname or "";
end

function FlagRSPConfigure:SetFullname(name)
    FlagRSPData.Fullname = name;
end

--[[

FlagRSPConfigure:GetName()

-- Returns the player's given name.

]]--

function FlagRSPConfigure:GetName(name)
	return FlagRSPData.Name or "";
end

--[[

FlagRSPConfigure:SetName(name)

-- Sets the player's given name to name.

]]--

function FlagRSPConfigure:SetName(name)
	FlagRSPData.Name = name;
end

--[[

FlagRSPConfigure:GetTitle()

-- Returns the player's title.

]]--

function FlagRSPConfigure:GetTitle()
	return FlagRSPData.Title or "";
end

--[[

FlagRSPConfigure:SetTitle(title)

-- Sets the player's title to title.

]]--

function FlagRSPConfigure:SetTitle(title)
	FlagRSPData.Title = title;
end

--[[

FlagRSPConfigure:GetDescription()

-- Returns the player's description.

]]--

function FlagRSPConfigure:GetDescription()
	return FlagRSPData.CharDesc or "";
end

--[[

FlagRSPConfigure:SetDescription(description)

-- Sets the player's description to description.

]]--

function FlagRSPConfigure:SetDescription(description)
	FlagRSPData.CharDesc = description;
end

--[[

FlagRSPConfigure:GetRevision()

-- Returns the description's revision number.

]]--

function FlagRSPConfigure:GetRevision()
	return FlagRSPData.CharDescRev or -1;
end

--[[

FlagRSPConfigure:SetRevision(revision)

-- Sets the description's revision number to revision.

]]--

function FlagRSPConfigure:SetRevision(revision)
	FlagRSPData.CharDescRev = revision;
end


--[[ === Configuration Functions ===]]--

--[[

FlagRSPConfigure:SetNameDisplay(state)

-- state is either true or false.

]]--
function FlagRSPConfigure:SetNameDisplay(state)
	FlagRSPData.nameChange = state;
end

--[[

FlagRSPConfigure:GetNameDisplay()

-- Returns true or false based on the state of nameChange.

]]--
function FlagRSPConfigure:GetNameDisplay()
	return FlagRSPData.nameChange;
end

--[[

FlagRSPConfigure:SetGuildDisplay(state)

-- state is a string that corresponds to an integer value in order to 
-- determine how to display guilds in a tooltip.
-- "all", 1 =>	-- Display all guilds
-- "known", 0 	-- Display only guilds known in Friendlist
-- "none", -1   -- Display no guilds

]]--
function FlagRSPConfigure:SetGuildDisplay(state)
	FlagRSPData.guildDisplay = state;
end

--[[

FlagRSPConfigure:GetGuildDisplay()

-- Returns the value stored in showGuilds as a string.

]]--
function FlagRSPConfigure:GetGuildDisplay()
	return FlagRSPData.guildDisplay;
end

--[[

FlagRSPConfigure:SetLevelDisplay(state)

-- state is a string value that causes two different flags to get set
-- depending on the string passed.
-- "color" => 	-- Enable coloring of the level text, disable alternate level display.
-- "relative" 	-- Disable coloring of the level text, enable alternate level display.
-- "none" 	-- Disable coloring of the level text, disable alternate level display.

]]--
function FlagRSPConfigure:SetLevelDisplay(state)
	FlagRSPData.levelText = state;
end

--[[

FlagRSPConfigure:GetLevelDisplay()

-- Returns the tooltip level display in the order Colored Level Display, Relative Level Display, None.

]]--
function FlagRSPConfigure:GetLevelDisplay()
	return FlagRSPData.levelText;
end

--[[

FlagRSPConfigure:SetPVPRanks(state)

-- Sets the rank display.

]]--
function FlagRSPConfigure:SetPVPRanks(state)
	FlagRSPData.showRanks = state;
end

--[[

FlagRSPConfigure:GetPVPRanks()

-- Returns the display value for the PVP Ranks.

]]--
function FlagRSPConfigure:GetPVPRanks()
	return FlagRSPData.showRanks;
end

--[[

FlagRSPConfigure:SetClassColor(state)

-- Sets the display of class colors.

]]--
function FlagRSPConfigure:SetClassColor(state)
	FlagRSPData.colorClassText = state;
end

--[[

FlagRSPConfigure:GetClassColor()

-- Returns the display value for class coloring.

]]--
function FlagRSPConfigure:GetClassColor()
	return FlagRSPData.colorClassText;
end

--[[

FlagRSPConfigure:SetGuildRank(state)

-- Sets the display value of the guild rank display.

]]--
function FlagRSPConfigure:SetGuildRank(state)
	FlagRSPData.showGuildRank = state;
end

--[[

FlagRSPConfigure:GetGuildRank()

-- Returns the display value for guild ranks.

]]--
function FlagRSPConfigure:GetGuildRank()
	return FlagRSPData.showGuildRank or false;
end

--[[

FlagRSPConfigure:SetButtonPosition(state)

-- State is an integer between 0 and 360 to position the button on the minimap.
-- TODO: Get around having to call FRIENDLISTMinimapButton:SetPoint().

]]--
function FlagRSPConfigure:SetButtonPosition(state)
	-- Save position.
	FlagRSPData.buttonPosition = state;

	-- Convert degree to radiant.
	local pos_rad = state * 2 * (3.1415926536 / 360);
	-- Radius of Minimap
	local r = 81.500;
   
	-- Polar coordinates, yummy.
	local x = math.floor(r * math.cos(pos_rad)+0.5)-12;
	local y = math.floor(r * math.sin(pos_rad)+0.5)+12;

	FRIENDLISTMinimapButton:SetPoint("TOPLEFT", "Minimap", "CENTER", x, y);
end

--[[

FlagRSPConfigure:GetButtonPosition()

-- Returns the current position of the minimap button.

]]--
function FlagRSPConfigure:GetButtonPosition()
	return FlagRSPData.buttonPosition;
end

--[[

FlagRSPConfigure:GetSoundsSetting()

-- Returns the state of the sound setting.

]]--
function FlagRSPConfigure:GetSoundsSetting()
	return FlagRSPData.playSounds;
end

--[[

FlagRSPConfigure:SetSoundsSetting(state)

-- Sets the playSounds variable to true or false.

]]--
function FlagRSPConfigure:SetSoundsSetting(state)
	FlagRSPData.playSounds = state;
end

--[[

FlagRSPConfigure:GetButtonState()

-- Returns whether the minimap button should be shown or hidden.

]]--
function FlagRSPConfigure:GetButtonState()
	return FlagRSPData.showMiniMapButtonNew;
end

--[[

FlagRSPConfigure:SetButtonState(state)

-- Sets whether the minimap button should be shown or hidden.

]]--
function FlagRSPConfigure:SetButtonState(state)
	FlagRSPData.showMiniMapButtonNew = state;
end

--[[

FlagRSPConfigure:GetVersionNotification()

-- Returns the version notification status.

]]--
function FlagRSPConfigure:GetVersionNotification()
	return FlagRSPData.ShowVersionNotification;
end

--[[

FlagRSPConfigure:SetVersionNotification(state)

-- Sets the version notification status.

]]--
function FlagRSPConfigure:SetVersionNotification(state)
	FlagRSPData.ShowVersionNotification = state;
end

--[[

FlagRSPConfigure:GetShowTips()

-- Returns whether or not to show tips.

]]--

function FlagRSPConfigure:GetShowTips()
	return FlagRSPData.ShowTips;
end

--[[

FlagRSPConfigure:SetShowTips(state)

-- Sets whether or not tips should be shown on log in.

]]--

function FlagRSPConfigure:SetShowTips(state)
	FlagRSPData.ShowTips = state;
end

--[[

FlagRSPConfigure:GetTooltipStyle()

-- Returns the current tooltip style.

]]--

function FlagRSPConfigure:GetTooltipStyle()
	return FlagRSPData.modifyTooltip;
end

--[[

FlagRSPConfigure:SetTooltipStyle(state)

-- Sets how FlagRSP should modify the tooltip.
-- "light" => Only minor modifications to the tooltip.
-- "normal" => Full modification of the tooltip.
-- "none" => Do not modify the tooltip.

]]--

function FlagRSPConfigure:SetTooltipStyle(state)
	FlagRSPData.modifyTooltip = state;
end

--[[

FlagRSPConfigure:GetStandby()

-- Returns whether FlagRSP is in standby or not.

]]--
function FlagRSPConfigure:GetStandby()
	return FlagRSPData.standby;
end

--[[

FlagRSPConfigure:SetStandby(state)

-- Sets whether FlagRSP is in standby or not.

]]--

function FlagRSPConfigure:SetStandby(state)
	FlagRSPData.standby = state;
end



--[[

FlagRSPConfigure:SetInfoBoxState(state)

-- Sets whether to show the info box or not.

]]

function FlagRSPConfigure:SetInfoBoxState(state)
	FlagRSPData.alwaysShowInfoBox = state;
end

--[[

FlagRSPConfigure:GetInfoBoxButtonCoords()

-- Returns x, y coordinates for the button on the target frame.

]]--

function FlagRSPConfigure:GetInfoBoxButtonCoords()
	return FlagRSPData.InfoBoxButtonX, FlagRSPData.InfoBoxButtonY;
end

--[[

FlagRSPConfigure:SetInfoBoxButtonCoords(x, y)

-- Sets the x, y coordinates for the button on the target frame to x, y.

]]

function FlagRSPConfigure:SetInfoBoxButtonCoords(x, y)
	FlagRSPData.InfoBoxButtonX = x;
	FlagRSPData.InfoBoxButtonY = y;
end

-- --[[

-- FlagRSPConfigure:GetSkinnableFancy()

-- -- Returns if SkinnableFancy is set.

-- ]]--

-- function FlagRSPConfigure:GetSkinnableFancy()
	-- -- return FlagRSPData.SkinnableFancy;
	-- return false;
-- end

-- --[[

-- FlagRSPConfigure:SetSkinnableFancy(state)

-- -- Sets SkinnableFancy to state.

-- ]]--

-- function FlagRSPConfigure:SetSkinnableFancy(state)
	-- FlagRSPData.SkinnableFancy = state;
-- end
-- end



--[[ === Friendlist Setting Functions ===]]--

--[[

FlagRSPConfigure:GetFriendlistEntryBox()

-- Returns whether the Friendlist Entry Box should be shown or hidden.

]]--

function FlagRSPConfigure:GetFriendlistEntryBox()
	return FlagRSPData.showFriendlistEntryBox;
end

--[[

FlagRSPConfigure:SetFriendlistEntryBox(state)

-- Sets whether the Friendlist Entry Box should be shown or hidden.

]]--

function FlagRSPConfigure:SetFriendlistEntryBox(state)
	FlagRSPData.showFriendlistEntryBox = state;
end

--[[

FlagRSPConfigure:GetFriendlistEntyBoxLocked()

]]--

function FlagRSPConfigure:GetFriendlistEntryBoxLocked()
	return FlagRSPData.FriendlistEntryBoxLocked;
end

--[[

FlagRSPConfigure:SetFriendlistEntryBoxLocked(state)

]]--

function FlagRSPConfigure:SetFriendlistEntryBoxLocked(state)
	FlagRSPData.FriendlistEntryBoxLocked = state;
end

--[[

FlagRSPConfigure:GetSortOrder()

-- Returns the current sorting order for the Friendlist.

]]--

function FlagRSPConfigure:GetSortOrder()
	return FlagRSPData.FriendlistSortOrder;
end

--[[

FlagRSPConfigure:SetSortOrder(state)

-- Sets the sorting order for the Friendlist to order.

]]--

function FlagRSPConfigure:SetSortOrder(order)
	FlagRSPData.FriendlistSortOrder = order;
end


--[[ === Info Box Functions ===]]--

--[[

FlagRSPConfigure:GetInfoBoxLocked()

]]--

function FlagRSPConfigure:GetInfoBoxLocked()
	return FlagRSPData.InfoBoxLocked;
end

--[[

FlagRSPConfigure:SetInfoBoxLocked(state)

]]--
function FlagRSPConfigure:SetInfoBoxLocked(state)
	FlagRSPData.InfoBoxLocked = state;
end

--[[

FlagRSPConfigure:GetInfoBoxCoords()

]]--
function FlagRSPConfigure:GetInfoBoxCoords()
	return FlagRSPData.InfoBoxX, FlagRSPData.InfoBoxY;
end

--[[

FlagRSPConfigure:SetInfoBoxCoords(x, y)

]]--
function FlagRSPConfigure:SetInfoBoxCoords(x, y)
	FlagRSPData.InfoBoxX = x;
	FlagRSPData.InfoBoxY = y;
end

--[[

FlagRSPConfigure:GetInfoBoxAutoPopUp()

]]--
function FlagRSPConfigure:GetInfoBoxAutoPopUp()
	return FlagRSPData.InfoBoxAutoPopUp;
end

--[[

FlagRSPConfigure:SetInfoBoxAutoPopUp(state)

]]--
function FlagRSPConfigure:SetInfoBoxAutoPopUp(state)
	FlagRSPData.InfoBoxAutoPopUp = state;
end

--[[

FlagRSPConfigure:GetDisplayInfoBox()

]]--
function FlagRSPConfigure:GetDisplayInfoBox()
	return FlagRSPData.displayInfoBox;
end

--[[

FlagRSPConfigure:SetDisplayInfoBox(state)

]]--
function FlagRSPConfigure:SetDisplayInfoBox(state)
	FlagRSPData.displayInfoBox = state;
end

--[[

FlagRSPConfigure:GetAlwaysShowInfoBox()

]]--
function FlagRSPConfigure:GetAlwaysShowInfoBox()
	return FlagRSPData.alwaysShowInfoBox;
end

--[[

FlagRSPConfigure:SetAlwaysShowInfoBox(state)

]]--
function FlagRSPConfigure:SetAlwaysShowInfoBox(state)
	FlagRSPData.alwaysShowInfoBox = state;
end

--[[

FlagRSPConfigure:GetInfoBoxWidth()

]]--
function FlagRSPConfigure:GetInfoBoxWidth()
	return FlagRSPData.InfoBoxWidth;
end

--[[

FlagRSPConfigure:SetInfoBoxWidth(width)

]]--
function FlagRSPConfigure:SetInfoBoxWidth(width)
	FlagRSPData.InfoBoxWidth = width;
end

--[[

FlagRSPConfigure:GetInfoBoxExpandUpwards()

]]--
function FlagRSPConfigure:GetInfoBoxExpandUpwards()
	return FlagRSPData.InfoBoxExpandUpwards;
end

--[[

FlagRSPConfigure:SetInfoBoxExpandUpwards(state)

]]--
function FlagRSPConfigure:SetInfoBoxExpandUpwards(state)
	FlagRSPData.InfoBoxExpandUpwards = state;
end

--[[

FlagRSPConfigure:GetInfoBoxAlphaBackdrop()

]]--
function FlagRSPConfigure:GetInfoBoxAlphaBackdrop()
	return FlagRSPData.InfoBoxAlphaBackdrop;
end

--[[

FlagRSPConfigure:SetInfoBoxAlphaBackdrop(alpha)

]]--
function FlagRSPConfigure:SetInfoBoxAlphaBackdrop(alpha)
	FlagRSPData.InfoBoxAlphaBackdrop = alpha;
end

--[[

FlagRSPConfigure:GetInfoBoxTextSize()

]]--
function FlagRSPConfigure:GetInfoBoxTextSize()
	return FlagRSPData.InfoBoxTextSize;
end

--[[

FlagRSPConfigure:SetInfoBoxTextSize(size)

]]--

function FlagRSPConfigure:SetInfoBoxTextSize(size)
	FlagRSPData.InfoBoxTextSize = size;
end

function FlagRSPConfigure:SetShowUnitName( display )
    if (display == nil or (display ~= false and display ~= true )) then
        display = false;
    end
    FlagRSPData.showUnitName = display;
end

function FlagRSPConfigure:GetShowUnitName()
    if ( FlagRSPData.showUnitName ) then
        return true;
    else
        return false;
    end
end

--[[

FlagRSPConfigure:GetOnlineListEntry(pos)

-- Returns the entry at pos from the numOnlineList.

]]--

function FlagRSPConfigure:GetOnlineListEntry(pos)
	return FlagRSPData.numOnlineList[pos];
end

--[[

FlagRSPConfigure:SetOnlineListEntry(pos, value)

-- Sets the entry at pos to value.

]]--

function FlagRSPConfigure:SetOnlineListEntry(pos, value)
	FlagRSPData.numOnlineList[pos] = value;
end

--[[

FlagRSPConfigure:GetOnlineListPosition()

-- Returns the position of the numOnlineList

]]--

function FlagRSPConfigure:GetOnlineListPosition()
	return FlagRSPData.numOnlineList.position;
end

--[[

FlagRSPConfigure:SetOnlineListPosition(pos)

-- Sets the position of the numOnlineList to pos

]]--

function FlagRSPConfigure:SetOnlineListPosition(pos)
	FlagRSPData.numOnlineList.position = pos;
end

--[[

FlagRSPConfigure:ConvertToPerCharacterSettings()

-- Much like the Friendlist version, this converts the old structure into a new
   per character structure.

]]--
function FlagRSPConfigure:ConvertToPerCharacterSettings()
	if ( FlagRSPData == nil ) then
		FlagRSPData = { };
	end
	
	if ( FlagRSPSettings[FlagRSP.rName][FlagRSP.pName] ~= nil ) then
		FlagRSPData = FlagRSPSettings[FlagRSP.rName][FlagRSP.pName];
		FlagRSPData.buttonPosition = Friendlist_Settings[FlagRSP.rName][FlagRSP.pName].buttonPosition;
		FlagRSPData.showMiniMapButtonNew = friendData[FlagRSP.rName][FlagRSP.pName].showMM;
		FlagRSPData.playSounds = friendData[FlagRSP.rName][FlagRSP.pName].playSounds;
		
		-- Convert settings stored as numbers into settings stored as strings.
		if ( FlagRSPData.modifyTooltip == 1 ) then
			FlagRSPData.modifyTooltip = "normal";
		elseif ( FlagRSPData.modifyTooltip == 0 ) then
			FlagRSPData.modifyTooltip = "light";
		else
			FlagRSPData.modifyTooltip = "none";
		end
		
		if ( FlagRSPData.showGuilds == 1 ) then
			FlagRSPData.guildDisplay = "all";
		elseif ( FlagRSPData.showGuilds == 0 ) then
			FlagRSPData.guildDisplay = "known";
		else
			FlagRSPData.guildDisplay = "none";
		end
		
		-- Combine the alternate level text and the colored level text into one variable.
		if ( FlagRSPData.levelChange == true ) then
			FlagRSPData.levelText = "relative";
		elseif ( FlagRSPData.colorLevelText == true ) then
			FlagRSPData.levelText = "color";
		else
			FlagRSPData.levelText = "none";
		end
	end
end

--[[

-- FlagRSPConfigure:loadCustoms()

-- - User custom settings as long as there is no GUI.

-- ]]--
-- function FlagRSPConfigure:loadCustoms() -- TODO remove
-- --[[

-- Put your individual settings here as long as there is no GUI available.

-- To do so just copy one or more settings from the function 
-- FlagRSPConfigure:InitializeSettings() above into this function. Then all you
-- have to do is replace the first 0 with your realm's name in "". The second 0
-- is for your player's name, also in "".

-- After the = set your wanted option. 

-- Note: If you just want the options as above (with the 0s) you don't have to
-- change anything. These settings are default settings. Only if you want to 
-- change them you have to set them here.

-- Examples:

-- -- Disable the InfoBox completely.
-- FlagRSPSettings["Your realms's name"]["Your player's name"].displayInfoBox = false;

-- -- Change width of InfoBox.
-- FlagRSPSettings["Cenarion Circle"]["Gurzilma"].InfoBoxWidth = 500;

-- -- Lock the InfoBox so you don't move it accidentally.
-- FlagRSPSettings["Aszshara"]["Ogrothok"].InfoBoxLocked = true;

-- -- Make the skinnable line's colour fancy.
-- FlagRSPSettings["Uther"]["Caelindia"].SkinnableFancy = true;

-- ]]--

-- end